--	LinkBuilder
--	Bundles functions used to prepare a scriptlink.


local major, minor, libTable = LibStub("LibBuilder-1.0"):GetLib()
if not libTable.canLoad then return end


local LinkBuilder, linkBuilder = libTable:NewClass("LinkBuilder")


function LinkBuilder:New()
	local instance = {}
	setmetatable(instance, self.instanceMetatable)
	return instance
end


---	Sets the label for the hyperlink.
--	@param	label	The new label.
function linkBuilder:SetLabel(label)
	self.label = label
end


---	Retrieves the hyperlink's label.
function linkBuilder:GetLabel()
	return self.label or ""
end


---	Sets the callback for the hyperlink.
--	@param	callback	Function closure or script to call when the link is clicked.
function linkBuilder:SetCallback(callback)
	local argType = type(callback)
	
	if argType == "function" then
		self.callback = callback
	elseif argType == "string" then
		local func, message = loadstring(callback)
		
		if not func then
			error("Could not compile callback")
		end
		
		self.callback = func
	else
		error("Invalid callback type")
	end
end


---	Retrieves the callback for the hyperlink
function linkBuilder:GetCallback()
	return self.callback
end


---	Sets the color for the hyperlink
--	@param	color	The new color.
function linkBuilder:SetColor(color)
	--	FIXME: check format
	self.color = color
end


---	Retrieves the color for the hyperlink
function linkBuilder:GetColor()
	return self.color or "ffffff33"	--	TODO: pick a default color
end


---	Builds a scriptlink from the current configuration.
--	NOTE: creates a different reference each time it's called
--	@return	scriptLink	The new scriptlink.
function linkBuilder:Build()
	local reference = libTable.classes.Core:RegisterCallback(self:GetCallback())
	
	local color = self:GetColor()
	local label = self:GetLabel()

	local scriptLink = string.format("|c%s|HScriptLink:ref:%s|h%s|h|r", color, reference, label)

	return scriptLink
end
