--	LibScriptLink
--	Implements a hyperlink scripting system that (hopefully) avoids taint.


local major, minor, libTable = LibStub("LibBuilder-1.0"):GetLib()
if not libTable.canLoad then return end


local interface = libTable.interface


---	Creates a basic scriptlink
--	@param	label		Text label for the scriptlink. Include brackets if you want them.
--	@param	callback	Callback function or script to call when the link is clicked.
--	@param	color		Color string for the link, eg. "ffffff00" for yellow.
--	@return	scriptlink	The new scriptlink text.
function interface:NewLink(label, callback, color)
	--	FIXME: 
	if not callback and not color then
		callback = label
		label = "[Click Here]"
	end
	
	local linkBuilder = libTable.classes.LinkBuilder:New()
	
	linkBuilder:SetLabel(label)
	linkBuilder:SetCallback(callback)
	
	if color then
		linkBuilder:SetColor(color)
	end
	
	return linkBuilder:Build()
end


--	deprecated
function interface:MakeLink(...)
	return self:NewLink(...)
end


---	Retrieves a new LinkBuilder object to access link features directly.
--	@return linkBuilder	The new LinkBuilder object.
function interface:NewLinkBuilder()
	return libTable.classes.LinkBuilder:New()
end


--	activates all function hooks
function interface:HookAll()
	libTable.classes.Core:HookAll()
end

--	deactivates all function hooks
function interface:UnhookAll()
	libTable.classes.Core:UnhookAll()
end
